Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(491)

Unified Diff: src/mips/builtins-mips.cc

Issue 1486563002: Remove {FIRST,LAST}_SPEC_OBJECT_TYPE. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/ic/x87/handler-compiler-x87.cc ('k') | src/mips/code-stubs-mips.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/mips/builtins-mips.cc
diff --git a/src/mips/builtins-mips.cc b/src/mips/builtins-mips.cc
index 496340dd55d17048f6f543cc89a389add0925142..95ea0d64f578196585dab613c4507ff04fdd8f36 100644
--- a/src/mips/builtins-mips.cc
+++ b/src/mips/builtins-mips.cc
@@ -587,9 +587,9 @@ static void Generate_JSConstructStubHelper(MacroAssembler* masm,
__ JumpIfSmi(v0, &use_receiver);
// If the type of the result (stored in its map) is less than
// FIRST_SPEC_OBJECT_TYPE, it is not an object in the ECMA sense.
__ GetObjectType(v0, a1, a3);
- __ Branch(&exit, greater_equal, a3, Operand(FIRST_SPEC_OBJECT_TYPE));
+ __ Branch(&exit, greater_equal, a3, Operand(FIRST_JS_RECEIVER_TYPE));
// Throw away the result of the constructor invocation and use the
// on-stack receiver as the result.
« no previous file with comments | « src/ic/x87/handler-compiler-x87.cc ('k') | src/mips/code-stubs-mips.cc » ('j') | no next file with comments »
@@ -587,9 +587,9 @@ static void Generate_JSConstructStubHelper(MacroAssembler* masm,
__ JumpIfSmi(v0, &use_receiver);
// If the type of the result (stored in its map) is less than
- // FIRST_SPEC_OBJECT_TYPE, it is not an object in the ECMA sense.
+ // FIRST_JS_RECEIVER_TYPE, it is not an object in the ECMA sense.
__ GetObjectType(v0, a1, a3);

Powered by Google App Engine
This is Rietveld 408576698